@@ -18,19 +18,19 @@ class Miner(ABC):
     """Base miner class"""
 
     @abstractmethod
-    def read_data(self):
+    def read_data(self, config: dict):
         """Reads data from its source"""
 
     @abstractmethod
-    def collect(self) -> Dict:
+    def collect(self, config: dict) -> Dict:
         """Collects all data"""
 
     @abstractmethod
-    def start_watching(self, observer: KartObserver):
+    def start_watching(self, config: dict, observer: KartObserver):
         """Start watching for data changes"""
 
     @abstractmethod
-    def stop_watching(self):
+    def stop_watching(self, config: dict):
         """Stop watching for data changes"""
 
 
@@ -42,48 +42,48 @@ class DefaultMiner(Miner):
         """Initializes miner. Must set the ``name`` and ``dir`` variables"""
 
     @abstractmethod
-    def collect_single_file(self, file: Path):
+    def collect_single_file(self, file: Path, config: dict):
         """Reads data from a single file"""
 
-    def read_data(self):
+    def read_data(self, config: dict):
         """Implements Miner.read_data().
 
         It iterates over a directory and calls collect_single_file() for each file
         """
         self.data = KartDict()
         for file in filter(Path.is_file, self.dir.iterdir()):
-            object = self.collect_single_file(file)
+            object = self.collect_single_file(file, config)
             if object:
                 self.data.update(object)
 
-    def collect(self):
+    def collect(self, config: dict):
         return {self.name: self.data}
 
-    def start_watching(self, observer: KartObserver):
+    def start_watching(self, config: dict, observer: KartObserver):
         """Registers a watchdog handler that calls collect_single_file() when a file has changed"""
 
         class Handler(RegexMatchingEventHandler):
             def on_moved(_, event):
                 self.data.pop(id_from_path(self.dir, Path(event.src_path)))
-                self.data.update(self.collect_single_file(Path(event.src_path)))
+                self.data.update(self.collect_single_file(Path(event.src_path), config))
 
             def on_modified(_, event):
-                self.data.update(self.collect_single_file(Path(event.src_path)))
+                self.data.update(self.collect_single_file(Path(event.src_path), config))
 
             def on_deleted(_, event):
                 self.data.pop(id_from_path(self.dir, Path(event.src_path)))
 
-        self.read_data()
+        self.read_data(config)
         observer.schedule(Handler(ignore_directories=True), self.dir, recursive=False)
 
-    def stop_watching(self):
+    def stop_watching(self, config: dict):
         """Implements Miner.stop_watching(). It does nothing as no cleanup is needed"""
 
 
 class DefaultMarkdownMiner(DefaultMiner):
     """Base miner that implements collect_single_file() for markdown files"""
 
-    def collect_single_file(self, file: Path) -> str:
+    def collect_single_file(self, file: Path, config: dict) -> str:
         """
         Stores the data included in the frontmatter in a dictionary, adds
         the markdown content in the ``content`` field and then return the dictionary
@@ -91,15 +91,14 @@ class DefaultMarkdownMiner(DefaultMiner):
         with file.open("r") as f:
             data = f.read().split("---")
             metadata = YamlLoader(data[1]).get_data()
+            if "draft" in metadata and metadata["draft"] and not config["serving"]:
+                return
             content = "---".join(data[2:])
             object = metadata
             slug = id_from_path(self.dir, file)
             object["slug"] = slug
             object["content"] = content
             object["content_type"] = "markdown"
-            if "draft" in object.keys():
-                if object["draft"]:
-                    return False
             return {slug: object}
 
 
@@ -140,7 +139,7 @@ class DefaultDataMiner(DefaultMiner):
         self.dir = Path(directory)
         self.name = "data"
 
-    def collect_single_file(self, file: Path) -> str:
+    def collect_single_file(self, file: Path, config: dict) -> str:
         """Users YamlLoader to get data from a yaml file"""
         with file.open("r") as f:
             slug = id_from_path(self.dir, file)
